;-----------------------------------------------------------------------;
;	Replay ST							;
;	Copyright (C) Karl Anders ygard, 15 December 1993		;
;-----------------------------------------------------------------------;
; Uses registers D5-D7/A6.						;
;									;
; Replay is started by calling MUSON in supervisor mode. Control is	;
; returned with sr=$2500 and timers A&D running. VBL and all other	;
; interrupts are turned off to prevent collision with OS.		;
; Calling MUSOFF will stop music.					;
;									;
; This routine uses the registers D5-D7 and A6 for internal uses, and	;
; such these registers *MUST NOT* be used as soon as MUSON has been	;
; called. Thus, this routine will not run concurrently with TOS.	;
;									;
; This routine needs some workspace after the module to work properly.	;
; I've set it to 16KB, some modules may need, some may need less. If	;
; the workspace is too small, execution will terminate on an ILLEGAL	;
; instruction. Adjust workspace size (WSPACE) to fit the specific	;
; module.								;
;									;
; MVOL = Main volume	  (Lower values lead to distortion, higher	;
;			   values imply more noise. $40 minimum, $100	;
;			   maximum, $60 recommended)			;
; FREQ = replay frequency (0=6.144kHz, 1=8.192kHz, 2=12.288kHz,		;
;			   3=16.384kHz, 4=24.576kHz (will not work on	;
;			   non-accelerated ST's)			;
; WSPACE = workspace size in bytes					;
;-----------------------------------------------------------------------;

WSPACE	EQU 16384			; Workspace size in bytes
MVOL	EQU $100			; >= $40 ($60 recommended)
FREQ	EQU 2				; 0=6.144, 1=8.192, 2=12.288
					; 3=16.384, 4=24.576

	IFEQ FREQ			; 6.144kHz
A_DATA	EQU 40
D_DATA	EQU 164
PARTS	EQU 3-1
INC	EQU $02469BC0			; 3579546/6144*65536
	ELSEIF
	IFEQ FREQ-1			; 8.192kHz
A_DATA	EQU 30
D_DATA	EQU 123
PARTS	EQU 4-1
INC	EQU $01B4F4D0			; 3579546/8192*65536
	ELSEIF
	IFEQ FREQ-2			; 12.288kHz
A_DATA	EQU 20
D_DATA	EQU 82
PARTS	EQU 6-1
INC	EQU $01234DE0			; 3579546/12288*65536
	ELSEIF
	IFEQ FREQ-3			; 16.384kHz
A_DATA	EQU 15
D_DATA	EQU 123
PARTS	EQU 4-1
INC	EQU $00DA7A68			; 3579546/16384*65536
	ELSEIF
	IFEQ FREQ-4			; 24.576kHz
A_DATA	EQU 10
D_DATA	EQU 82
PARTS	EQU 6-1
INC	EQU $00910000			; 3579546/24576*65536
	ELSEIF
	FAIL
	END
	ENDC
	ENDC
	ENDC
	ENDC
	ENDC

;-------------------------8<----- Cut here -----8<----------------------;
;			Demo bit which starts replay.			;

	clr.l	-(sp)
	move.w	#$0020,-(sp)
	trap	#1
	addq.w	#6,sp
	move.l	d0,-(sp)

	bsr.s	muson				; Install music

waitspc	btst	#0,$FFFFFC00.w			; Wait for key
	beq.s	waitspc
	cmpi.b	#$B9,$FFFFFC02.w
	bne.s	waitspc

	bsr	musoff				; Restore system completely

	move.w	#$0020,-(sp)
	trap	#1
	addq.w	#6,sp

	pea	$004C0000
	trap	#1

;-------------------------8<----- Cut here -----8<----------------------;

;---------------------------------------------------- Interrupts on/off --
muson	bsr	vol				; Calculate volume tables
	bsr	incrcal				; Calculate tonetables
	bsr	clearym				; Clear soundchip registers

	jsr	mt_init				; Initialize music

	cmp.l	#workspc-mt_data,d1
	ble.s	memok
	illegal

memok	jsr	mt_prepare			; Prepare samples

	move	#$2700,sr

	move.l	$FFFFFA06.w,s06			; Save MFP registers
	move.l	$FFFFFA12.w,s12
	move.b	$FFFFFA1D.w,s1d

	move.l	#$FF20FF10,$FFFFFA06.w		; Timer A & D on
	move.l	#$FF20FF10,$FFFFFA12.w

	bclr	#3,$FFFFFA17.w			; Autovectors

	clr.b	$FFFFFA19.w
	clr.b	$FFFFFA1D.w

	move.b	#A_DATA,$FFFFFA1F.w
	move.b	#D_DATA,$FFFFFA25.w

	move.b	#2,$FFFFFA19.w
	move.b	#$06,$FFFFFA1D.w

	move.l	$00000110.w,oldtimd
	move.l	$00000134.w,oldtima
	move.l	#timerd,$00000110.w
	move.l	#playvec,$00000134.w

	lea	sample1(pc),a6

	move	#$2500,sr
	rts

musoff	move	#$2700,sr

	move.l	oldtimd(pc),$00000110.w		; Restore vectors
	move.l	oldtima(pc),$00000134.w

	move.l	s06(pc),$FFFFFA06.w
	move.l	s12(pc),$FFFFFA12.w
	move.b	s1d(pc),$FFFFFA1D.w

	bset	#3,$FFFFFA17.w			; Softvectors

	move	#$2300,sr
	rts

s06	DC.L 0
s12	DC.L 0
s1d	DC.B 0
	EVEN

oldtimd	DC.L 0
oldtima	DC.L 0

;-------------------------------------------- Clear soundchip registers --
clearym	move	#$2700,sr

	moveq	#$0A,d0
._1	move.b	d0,$FFFF8800.w
	clr.b	$FFFF8802.w
	dbra	d0,._1				; Clear soundchip registers
	clr.b	$FFFF8800.w
	clr.b	$FFFF8802.w
	move.b	#7,$FFFF8800.w
	move.b	#$FF,$FFFF8802.w

	rts

;----------------------------------------------- Calculate volume table --
vol	moveq	#64,d0
	lea	vtabend(pc),a0

.ploop	move.w	#255,d1
.mloop	move.w	d1,d2
	ext.w	d2
	muls	d0,d2
	divs	#MVOL,d2			; <---- Master volume
	add.b	#$80,d2
	move.b	d2,-(a0)
	dbra	d1,.mloop
	dbra	d0,.ploop

	rts

vtab	DS.B 65*256
vtabend:

;-------------------------------------------- Calculate increment-table --
incrcal	lea	stab(pc),a0
	move.w	#$0030,d1
	move.w	#$039F-$0030,d0
	move.l	#INC,d2

recalc	swap	d2
	moveq	#0,d3
	move.w	d2,d3
	divu	d1,d3
	move.w	d3,d4
	swap	d4

	swap	d2
	move.w	d2,d3
	divu	d1,d3
	move.w	d3,d4
	move.l	d4,(a0)+

	addq.w	#1,d1
	dbra	d0,recalc
	rts

itab	DS.L $0030
stab	DS.L $03A0-$0030

;---------------------------------------------------- Samplecalculating --
timerd	movea.l	samp2(pc),a6

	move	#$2500,sr
	movem.l	d0-d4/a0-a4,-(sp)

	subq.w	#1,count
	bpl.s	.nomus

	move.w	#PARTS,count
	bsr	mt_music

.nomus	move.l	samp2(pc),d0
	move.l	samp1(pc),samp2
	move.l	d0,samp1

	lea	itab(pc),a2
	lea	vtab(pc),a4

	movea.l	rep1lc(pc),a0
	move.w	rep1frc(pc),d1

	move.w	aud1per(pc),d4
	add.w	d4,d4
	add.w	d4,d4
	move.w	0(a2,d4.w),d3
	move.w	2(a2,d4.w),d2

	move.w	aud1vol(pc),d4
	asl.w	#8,d4
	lea	0(a4,d4.w),a1

	movea.l	samp2(pc),a3
	moveq	#0,d4
	moveq	#0,d0

	IFGE FREQ-3
	bsr	v123

	adda.l	d0,a0
	moveq	#0,d0
	cmpa.l	rep1end(pc),a0
	blt.s	.ok1_1
	suba.l	rep1rpt(pc),a0
.ok1_1
	ENDC
	bsr	v123

	adda.l	d0,a0
	cmpa.l	rep1end(pc),a0
	blt.s	.ok1_2
	suba.l	rep1rpt(pc),a0

.ok1_2	move.l	a0,rep1lc
	move.w	d1,rep1frc


	movea.l	rep2lc(pc),a0
	move.w	rep2frc(pc),d1

	move.w	aud2per(pc),d4
	add.w	d4,d4
	add.w	d4,d4
	move.w	0(a2,d4.w),d3
	move.w	2(a2,d4.w),d2

	move.w	aud2vol(pc),d4
	asl.w	#8,d4
	lea	0(a4,d4.w),a1

	movea.l	samp2(pc),a3
	moveq	#0,d4
	moveq	#0,d0

	IFGE FREQ-3
	bsr	v234

	adda.l	d0,a0
	moveq	#0,d0
	cmpa.l	rep2end(pc),a0
	blt.s	.ok2_1
	suba.l	rep2rpt(pc),a0
.ok2_1
	ENDC
	bsr	v234

	adda.l	d0,a0
	cmpa.l	rep2end(pc),a0
	blt.s	.ok2_2
	suba.l	rep2rpt(pc),a0

.ok2_2	move.l	a0,rep2lc
	move.w	d1,rep2frc


	movea.l	rep3lc(pc),a0
	move.w	rep3frc(pc),d1

	move.w	aud3per(pc),d4
	add.w	d4,d4
	add.w	d4,d4
	move.w	0(a2,d4.w),d3
	move.w	2(a2,d4.w),d2

	move.w	aud3vol(pc),d4
	asl.w	#8,d4
	lea	0(a4,d4.w),a1

	movea.l	samp2(pc),a3
	moveq	#0,d4
	moveq	#0,d0

	IFGE FREQ-3
	bsr	v234

	adda.l	d0,a0
	moveq	#0,d0
	cmpa.l	rep3end(pc),a0
	blt.s	.ok3_1
	suba.l	rep3rpt(pc),a0
.ok3_1
	ENDC
	bsr	v234

	adda.l	d0,a0
	cmpa.l	rep3end(pc),a0
	blt.s	.ok3_2
	suba.l	rep3rpt(pc),a0

.ok3_2	move.l	a0,rep3lc
	move.w	d1,rep3frc


	movea.l	rep4lc(pc),a0
	move.w	rep4frc(pc),d1

	move.w	aud4per(pc),d4
	add.w	d4,d4
	add.w	d4,d4
	move.w	0(a2,d4.w),d3
	move.w	2(a2,d4.w),d2

	move.w	aud4vol(pc),d4
	asl.w	#8,d4
	lea	0(a4,d4.w),a1

	movea.l	samp2(pc),a3
	moveq	#0,d4
	moveq	#0,d0

	IFGE FREQ-3
	bsr	v234

	adda.l	d0,a0
	moveq	#0,d0
	cmpa.l	rep4end(pc),a0
	blt.s	.ok4_1
	suba.l	rep4rpt(pc),a0
.ok4_1
	ENDC
	bsr	v234

	adda.l	d0,a0
	cmpa.l	rep4end(pc),a0
	blt.s	.ok4_2
	suba.l	rep4rpt(pc),a0

.ok4_2	move.l	a0,rep4lc
	move.w	d1,rep4frc

	movem.l	(sp)+,d0-d4/a0-a4
	rte

v123	REPT 41
	add.w	d2,d1
	addx.w	d3,d0
	move.b	0(a0,d0.w),d4
	move.b	0(a1,d4.w),d4
	move.w	d4,(a3)+
	ENDR

	rts

v234	REPT 41
	add.w	d2,d1
	addx.w	d3,d0
	move.b	0(a0,d0.w),d4
	move.b	0(a1,d4.w),d4
	add.w	d4,(a3)+
	ENDR

	rts

;-------------------------------------------- Hardware-registers & data --
count	DC.W PARTS

rep1lc	DC.L sample1
rep1rpt	DC.L 0
rep1end	DC.L 0
rep1frc	DC.W 0
	DC.W 0

rep2lc	DC.L sample1
rep2rpt	DC.L 0
rep2end	DC.L 0
rep2frc	DC.W 0
	DC.W 0

rep3lc	DC.L sample1
rep3rpt	DC.L 0
rep3end	DC.L 0
rep3frc	DC.W 0
	DC.W 0

rep4lc	DC.L sample1
rep4rpt	DC.L 0
rep4end	DC.L 0
rep4frc	DC.W 0
	DC.W 0

aud1lc	DC.L dummy
aud1len	DC.W 0
aud1per	DC.W 0
aud1vol	DC.W 0
	DS.W 3

aud2lc	DC.L dummy
aud2len	DC.W 0
aud2per	DC.W 0
aud2vol	DC.W 0
	DS.W 3

aud3lc	DC.L dummy
aud3len	DC.W 0
aud3per	DC.W 0
aud3vol	DC.W 0
	DS.W 3

aud4lc	DC.L dummy
aud4len	DC.W 0
aud4per	DC.W 0
aud4vol	DC.W 0

dmactrl	DC.W 0
dummy	DC.L 0

samp1	DC.L sample1
samp2	DC.L sample2

sample1	REPT 82
	DC.W $0200
	ENDR

sample2	REPT 82
	DC.W $0200
	ENDR

;--------------------------------------------------- Playback-interrupt --
; The more advanced coders may like to change this to their own liking
playvec	move.w	(a6)+,d7
	lsl.w	#4,d7
	movem.l	snd_tab(pc,d7.w),d5-d7
	movem.l	d5-d7,$FFFF8800.w
	rte

;--------------------------------------------- Sound data for soundchip --
snd_tab	REPT 384
	DC.L $08000F00,$09000A00,$0A000000,0
	ENDR

	DC.L $08000F00,$09000A00,$0A000000,0
	DC.L $08000F00,$09000A00,$0A000000,0
	DC.L $08000F00,$09000900,$0A000900,0
	DC.L $08000F00,$09000900,$0A000900,0
	DC.L $08000F00,$09000900,$0A000800,0
	DC.L $08000F00,$09000900,$0A000800,0
	DC.L $08000F00,$09000800,$0A000700,0
	DC.L $08000F00,$09000800,$0A000700,0
	DC.L $08000E00,$09000B00,$0A000D00,0
	DC.L $08000E00,$09000B00,$0A000D00,0
	DC.L $08000E00,$09000D00,$0A000B00,0
	DC.L $08000E00,$09000D00,$0A000B00,0
	DC.L $08000E00,$09000A00,$0A000D00,0
	DC.L $08000E00,$09000A00,$0A000D00,0
	DC.L $08000E00,$09000C00,$0A000C00,0
	DC.L $08000E00,$09000C00,$0A000C00,0
	DC.L $08000E00,$09000D00,$0A000A00,0
	DC.L $08000E00,$09000D00,$0A000A00,0
	DC.L $08000E00,$09000D00,$0A000900,0
	DC.L $08000E00,$09000D00,$0A000900,0
	DC.L $08000E00,$09000D00,$0A000800,0
	DC.L $08000E00,$09000D00,$0A000800,0
	DC.L $08000E00,$09000D00,$0A000700,0
	DC.L $08000E00,$09000D00,$0A000700,0
	DC.L $08000E00,$09000D00,$0A000000,0
	DC.L $08000E00,$09000D00,$0A000000,0
	DC.L $08000B00,$09000E00,$0A000C00,0
	DC.L $08000B00,$09000E00,$0A000C00,0
	DC.L $08000E00,$09000B00,$0A000C00,0
	DC.L $08000E00,$09000B00,$0A000C00,0
	DC.L $08000E00,$09000C00,$0A000B00,0
	DC.L $08000E00,$09000C00,$0A000B00,0
	DC.L $08000A00,$09000E00,$0A000C00,0
	DC.L $08000A00,$09000E00,$0A000C00,0
	DC.L $08000E00,$09000A00,$0A000C00,0
	DC.L $08000E00,$09000A00,$0A000C00,0
	DC.L $08000E00,$09000C00,$0A000A00,0
	DC.L $08000E00,$09000C00,$0A000A00,0
	DC.L $08000E00,$09000900,$0A000C00,0
	DC.L $08000E00,$09000900,$0A000C00,0
	DC.L $08000E00,$09000C00,$0A000900,0
	DC.L $08000E00,$09000C00,$0A000900,0
	DC.L $08000E00,$09000C00,$0A000800,0
	DC.L $08000E00,$09000C00,$0A000800,0
	DC.L $08000E00,$09000C00,$0A000800,0
	DC.L $08000E00,$09000C00,$0A000700,0
	DC.L $08000E00,$09000C00,$0A000700,0
	DC.L $08000E00,$09000C00,$0A000600,0
	DC.L $08000E00,$09000C00,$0A000300,0
	DC.L $08000D00,$09000D00,$0A000B00,0
	DC.L $08000D00,$09000D00,$0A000B00,0
	DC.L $08000D00,$09000D00,$0A000B00,0
	DC.L $08000E00,$09000B00,$0A000A00,0
	DC.L $08000E00,$09000B00,$0A000A00,0
	DC.L $08000D00,$09000C00,$0A000C00,0
	DC.L $08000D00,$09000C00,$0A000C00,0
	DC.L $08000D00,$09000C00,$0A000C00,0
	DC.L $08000D00,$09000D00,$0A000A00,0
	DC.L $08000D00,$09000D00,$0A000A00,0
	DC.L $08000E00,$09000B00,$0A000800,0
	DC.L $08000E00,$09000B00,$0A000800,0
	DC.L $08000E00,$09000B00,$0A000800,0
	DC.L $08000D00,$09000D00,$0A000900,0
	DC.L $08000D00,$09000D00,$0A000900,0
	DC.L $08000E00,$09000A00,$0A000900,0
	DC.L $08000E00,$09000A00,$0A000900,0
	DC.L $08000D00,$09000D00,$0A000800,0
	DC.L $08000D00,$09000D00,$0A000700,0
	DC.L $08000D00,$09000D00,$0A000600,0
	DC.L $08000D00,$09000D00,$0A000600,0
	DC.L $08000E00,$09000900,$0A000900,0
	DC.L $08000E00,$09000900,$0A000900,0
	DC.L $08000E00,$09000800,$0A000900,0
	DC.L $08000E00,$09000800,$0A000900,0
	DC.L $08000E00,$09000900,$0A000800,0
	DC.L $08000E00,$09000900,$0A000800,0
	DC.L $08000E00,$09000700,$0A000900,0
	DC.L $08000E00,$09000900,$0A000700,0
	DC.L $08000E00,$09000900,$0A000700,0
	DC.L $08000E00,$09000900,$0A000600,0
	DC.L $08000E00,$09000900,$0A000600,0
	DC.L $08000E00,$09000800,$0A000700,0
	DC.L $08000E00,$09000800,$0A000700,0
	DC.L $08000E00,$09000800,$0A000600,0
	DC.L $08000E00,$09000800,$0A000600,0
	DC.L $08000E00,$09000800,$0A000400,0
	DC.L $08000E00,$09000800,$0A000400,0
	DC.L $08000E00,$09000700,$0A000500,0
	DC.L $08000E00,$09000700,$0A000400,0
	DC.L $08000E00,$09000700,$0A000300,0
	DC.L $08000E00,$09000600,$0A000400,0
	DC.L $08000E00,$09000600,$0A000300,0
	DC.L $08000E00,$09000500,$0A000400,0
	DC.L $08000E00,$09000500,$0A000200,0
	DC.L $08000E00,$09000400,$0A000200,0
	DC.L $08000E00,$09000300,$0A000200,0
	DC.L $08000E00,$09000000,$0A000000,0
	DC.L $08000D00,$09000B00,$0A000A00,0
	DC.L $08000D00,$09000B00,$0A000A00,0
	DC.L $08000A00,$09000C00,$0A000C00,0
	DC.L $08000A00,$09000C00,$0A000C00,0
	DC.L $08000C00,$09000A00,$0A000C00,0
	DC.L $08000D00,$09000900,$0A000B00,0
	DC.L $08000D00,$09000900,$0A000B00,0
	DC.L $08000D00,$09000B00,$0A000900,0
	DC.L $08000D00,$09000B00,$0A000900,0
	DC.L $08000D00,$09000B00,$0A000900,0
	DC.L $08000D00,$09000A00,$0A000A00,0
	DC.L $08000D00,$09000A00,$0A000A00,0
	DC.L $08000900,$09000C00,$0A000C00,0
	DC.L $08000C00,$09000C00,$0A000900,0
	DC.L $08000C00,$09000C00,$0A000900,0
	DC.L $08000C00,$09000C00,$0A000900,0
	DC.L $08000800,$09000C00,$0A000C00,0
	DC.L $08000800,$09000C00,$0A000C00,0
	DC.L $08000C00,$09000C00,$0A000800,0
	DC.L $08000C00,$09000C00,$0A000800,0
	DC.L $08000D00,$09000B00,$0A000400,0
	DC.L $08000D00,$09000B00,$0A000400,0
	DC.L $08000C00,$09000C00,$0A000700,0
	DC.L $08000C00,$09000C00,$0A000600,0
	DC.L $08000C00,$09000C00,$0A000600,0
	DC.L $08000C00,$09000C00,$0A000500,0
	DC.L $08000D00,$09000A00,$0A000700,0
	DC.L $08000D00,$09000A00,$0A000600,0
	DC.L $08000D00,$09000A00,$0A000600,0
	DC.L $08000D00,$09000A00,$0A000500,0
	DC.L $08000D00,$09000900,$0A000800,0
	DC.L $08000C00,$09000B00,$0A000900,0
	DC.L $08000B00,$09000B00,$0A000B00,0
	DC.L $08000D00,$09000800,$0A000800,0
	DC.L $08000D00,$09000800,$0A000800,0
	DC.L $08000C00,$09000B00,$0A000800,0
	DC.L $08000D00,$09000900,$0A000500,0
	DC.L $08000D00,$09000900,$0A000400,0
	DC.L $08000D00,$09000800,$0A000600,0
	DC.L $08000C00,$09000B00,$0A000700,0
	DC.L $08000D00,$09000700,$0A000700,0
	DC.L $08000C00,$09000B00,$0A000600,0
	DC.L $08000B00,$09000B00,$0A000A00,0
	DC.L $08000800,$09000A00,$0A000C00,0
	DC.L $08000C00,$09000B00,$0A000200,0
	DC.L $08000C00,$09000A00,$0A000800,0
	DC.L $08000C00,$09000B00,$0A000000,0
	DC.L $08000D00,$09000600,$0A000400,0
	DC.L $08000D00,$09000500,$0A000500,0
	DC.L $08000C00,$09000900,$0A000900,0
	DC.L $08000D00,$09000500,$0A000400,0
	DC.L $08000B00,$09000B00,$0A000900,0
	DC.L $08000D00,$09000400,$0A000300,0
	DC.L $08000B00,$09000A00,$0A000A00,0
	DC.L $08000C00,$09000A00,$0A000500,0
	DC.L $08000C00,$09000900,$0A000800,0
	DC.L $08000B00,$09000B00,$0A000800,0
	DC.L $08000C00,$09000A00,$0A000000,0
	DC.L $08000C00,$09000A00,$0A000000,0
	DC.L $08000C00,$09000900,$0A000700,0
	DC.L $08000B00,$09000B00,$0A000700,0
	DC.L $08000C00,$09000900,$0A000600,0
	DC.L $08000B00,$09000A00,$0A000900,0
	DC.L $08000B00,$09000B00,$0A000600,0
	DC.L $08000A00,$09000A00,$0A000A00,0
	DC.L $08000B00,$09000B00,$0A000500,0
	DC.L $08000B00,$09000A00,$0A000800,0
	DC.L $08000B00,$09000B00,$0A000200,0
	DC.L $08000C00,$09000700,$0A000700,0
	DC.L $08000C00,$09000800,$0A000400,0
	DC.L $08000C00,$09000700,$0A000600,0
	DC.L $08000B00,$09000900,$0A000900,0
	DC.L $08000A00,$09000A00,$0A000900,0
	DC.L $08000C00,$09000600,$0A000600,0
	DC.L $08000C00,$09000700,$0A000300,0
	DC.L $08000B00,$09000A00,$0A000500,0
	DC.L $08000B00,$09000900,$0A000800,0
	DC.L $08000B00,$09000A00,$0A000300,0
	DC.L $08000A00,$09000A00,$0A000800,0
	DC.L $08000B00,$09000A00,$0A000000,0
	DC.L $08000B00,$09000900,$0A000700,0
	DC.L $08000B00,$09000800,$0A000800,0
	DC.L $08000A00,$09000900,$0A000900,0
	DC.L $08000A00,$09000A00,$0A000700,0
	DC.L $08000C00,$09000100,$0A000100,0
	DC.L $08000A00,$09000A00,$0A000600,0
	DC.L $08000B00,$09000800,$0A000700,0
	DC.L $08000A00,$09000A00,$0A000500,0
	DC.L $08000A00,$09000900,$0A000800,0
	DC.L $08000A00,$09000A00,$0A000400,0
	DC.L $08000A00,$09000A00,$0A000300,0
	DC.L $08000A00,$09000A00,$0A000200,0
	DC.L $08000900,$09000900,$0A000900,0
	DC.L $08000A00,$09000800,$0A000800,0
	DC.L $08000B00,$09000800,$0A000100,0
	DC.L $08000A00,$09000900,$0A000600,0
	DC.L $08000B00,$09000700,$0A000400,0
	DC.L $08000A00,$09000900,$0A000500,0
	DC.L $08000900,$09000900,$0A000800,0
	DC.L $08000A00,$09000900,$0A000300,0
	DC.L $08000A00,$09000800,$0A000600,0
	DC.L $08000900,$09000900,$0A000700,0
	DC.L $08000A00,$09000900,$0A000000,0
	DC.L $08000900,$09000800,$0A000800,0
	DC.L $08000A00,$09000800,$0A000400,0
	DC.L $08000900,$09000900,$0A000600,0
	DC.L $08000A00,$09000800,$0A000100,0
	DC.L $08000900,$09000900,$0A000500,0
	DC.L $08000900,$09000800,$0A000700,0
	DC.L $08000800,$09000800,$0A000800,0
	DC.L $08000900,$09000800,$0A000600,0
	DC.L $08000900,$09000900,$0A000200,0
	DC.L $08000900,$09000700,$0A000700,0
	DC.L $08000900,$09000900,$0A000000,0
	DC.L $08000800,$09000800,$0A000700,0
	DC.L $08000900,$09000700,$0A000600,0
	DC.L $08000800,$09000800,$0A000600,0
	DC.L $08000900,$09000800,$0A000200,0
	DC.L $08000900,$09000600,$0A000600,0
	DC.L $08000800,$09000700,$0A000700,0
	DC.L $08000800,$09000800,$0A000400,0
	DC.L $08000800,$09000700,$0A000600,0
	DC.L $08000800,$09000800,$0A000200,0
	DC.L $08000700,$09000700,$0A000700,0
	DC.L $08000800,$09000600,$0A000600,0
	DC.L $08000800,$09000700,$0A000400,0
	DC.L $08000700,$09000700,$0A000600,0
	DC.L $08000800,$09000600,$0A000500,0
	DC.L $08000800,$09000600,$0A000400,0
	DC.L $08000700,$09000600,$0A000600,0
	DC.L $08000700,$09000700,$0A000400,0
	DC.L $08000800,$09000500,$0A000400,0
	DC.L $08000600,$09000600,$0A000600,0
	DC.L $08000700,$09000600,$0A000400,0
	DC.L $08000700,$09000500,$0A000500,0
	DC.L $08000600,$09000600,$0A000500,0
	DC.L $08000600,$09000600,$0A000400,0
	DC.L $08000600,$09000500,$0A000500,0
	DC.L $08000600,$09000600,$0A000200,0
	DC.L $08000600,$09000500,$0A000400,0
	DC.L $08000500,$09000500,$0A000500,0
	DC.L $08000600,$09000500,$0A000200,0
	DC.L $08000500,$09000500,$0A000400,0
	DC.L $08000500,$09000400,$0A000400,0
	DC.L $08000500,$09000500,$0A000200,0
	DC.L $08000400,$09000400,$0A000400,0
	DC.L $08000400,$09000400,$0A000300,0
	DC.L $08000400,$09000400,$0A000200,0
	DC.L $08000400,$09000300,$0A000300,0
	DC.L $08000300,$09000300,$0A000300,0
	DC.L $08000300,$09000300,$0A000200,0
	DC.L $08000300,$09000200,$0A000200,0
	DC.L $08000200,$09000200,$0A000200,0
	DC.L $08000200,$09000200,$0A000100,0
	DC.L $08000100,$09000100,$0A000100,0
	DC.L $08000200,$09000100,$0A000000,0
	DC.L $08000100,$09000100,$0A000000,0
	DC.L $08000100,$09000000,$0A000000,0
	DC.L $08000000,$09000000,$0A000000,0

	REPT 384
	DC.L $08000000,$09000000,$0A000000,0
	ENDR

	INCLUDE	replay.s

mt_data	INCBIN 'D:\HISCORE.MOD'

	DS.B WSPACE				; Workspace
workspc	DS.W 1

	END
